Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(138)

Unified Diff: src/core/SkMatrixImageFilter.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/core/SkMatrix.cpp ('k') | src/core/SkMatrixImageFilter.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkMatrixImageFilter.h
diff --git a/src/core/SkMatrixImageFilter.h b/src/core/SkMatrixImageFilter.h
index 83f2cfaf338b0e2882dea72c6827b5314e09fc6c..86734b629cfdc0ad95073d3bfad992080a23b055 100644
--- a/src/core/SkMatrixImageFilter.h
+++ b/src/core/SkMatrixImageFilter.h
@@ -24,13 +24,13 @@ public:
/** Construct a 2D transformation image filter.
* @param transform The matrix to apply when drawing the src bitmap
* @param filterLevel The quality of filtering to apply when scaling.
* @param input The input image filter. If NULL, the src bitmap
* passed to filterImage() is used instead.
*/
static SkMatrixImageFilter* Create(const SkMatrix& transform,
SkFilterQuality,
- SkImageFilter* input = NULL);
+ SkImageFilter* input = nullptr);
virtual ~SkMatrixImageFilter();
void computeFastBounds(const SkRect&, SkRect*) const override;
« no previous file with comments | « src/core/SkMatrix.cpp ('k') | src/core/SkMatrixImageFilter.cpp » ('j') | no next file with comments »
@@ -24,13 +24,13 @@ public:
* @param transform The matrix to apply when drawing the src bitmap
* @param filterLevel The quality of filtering to apply when scaling.
- * @param input The input image filter. If NULL, the src bitmap
+ * @param input The input image filter. If nullptr, the src bitmap
* passed to filterImage() is used instead.
*/

Powered by Google App Engine
This is Rietveld 408576698